@@ -16,6 +16,7 @@ import logging
 import codecs
 import errno
 import stat
+from datetime import datetime
 from threading import Lock
 
 from sos.utilities import sos_get_command_output, is_executable
@@ -25,11 +26,6 @@ try:
 except ImportError:
     pass
 
-# PYCOMPAT
-import six
-if six.PY3:
-    long = int
-
 P_FILE = "file"
 P_LINK = "link"
 P_NODE = "node"
@@ -122,7 +118,7 @@ class Archive(object):
         """Finalize an archive object via method. This may involve creating
         An archive that is subsequently compressed or simply closing an
         archive that supports in-line handling. If method is automatic then
-        the following methods are tried in order: xz, bz2 and gzip"""
+        the following methods are tried in order: xz, gzip"""
 
         self.close()
 
@@ -135,13 +131,15 @@ class FileCacheArchive(Archive):
     _archive_root = ""
     _archive_name = ""
 
-    def __init__(self, name, tmpdir, policy, threads, enc_opts, sysroot):
+    def __init__(self, name, tmpdir, policy, threads, enc_opts, sysroot,
+                 manifest=None):
         self._name = name
         self._tmp_dir = tmpdir
         self._policy = policy
         self._threads = threads
         self.enc_opts = enc_opts
-        self.sysroot = sysroot
+        self.sysroot = sysroot or '/'
+        self.manifest = manifest
         self._archive_root = os.path.join(tmpdir, name)
         with self._path_lock:
             os.makedirs(self._archive_root, 0o700)
@@ -342,14 +340,14 @@ class FileCacheArchive(Archive):
                 # path case
                 try:
                     shutil.copy(src, dest)
+                except OSError as e:
+                    self.log_info("File not collected: '%s'" % e)
                 except IOError as e:
                     # Filter out IO errors on virtual file systems.
                     if src.startswith("/sys/") or src.startswith("/proc/"):
                         pass
                     else:
                         self.log_info("caught '%s' copying '%s'" % (e, src))
-                except OSError as e:
-                    self.log_info("File not collected: '%s'" % e)
 
                 # copy file attributes, skip SELinux xattrs for /sys and /proc
                 try:
@@ -537,6 +535,29 @@ class FileCacheArchive(Archive):
         if os.path.isdir(self._archive_root):
             shutil.rmtree(self._archive_root)
 
+    def add_final_manifest_data(self, method):
+        """Adds component-agnostic data to the manifest so that individual
+        SoSComponents do not need to redundantly add these manually
+        """
+        end = datetime.now()
+        start = self.manifest.start_time
+        run_time = end - start
+        self.manifest.add_field('end_time', end)
+        self.manifest.add_field('run_time', run_time)
+        self.manifest.add_field('compression', method)
+        self.add_string(self.manifest.get_json(indent=4),
+                        os.path.join('sos_reports', 'manifest.json'))
+
+    def rename_archive_root(self, cleaner):
+        """Rename the archive to an obfuscated version using an initialized
+        SoSCleaner instance
+        """
+        self._name = cleaner.obfuscate_string(self._name)
+        _new_root = os.path.join(self._tmp_dir, self._name)
+        os.rename(self._archive_root, _new_root)
+        self._archive_root = _new_root
+        self._archive_name = os.path.join(self._tmp_dir, self.name())
+
     def finalize(self, method):
         self.log_info("finalizing archive '%s' using method '%s'"
                       % (self._archive_root, method))
@@ -612,9 +633,10 @@ class TarFileArchive(FileCacheArchive):
     method = None
     _with_selinux_context = False
 
-    def __init__(self, name, tmpdir, policy, threads, enc_opts, sysroot):
+    def __init__(self, name, tmpdir, policy, threads, enc_opts, sysroot,
+                 manifest=None):
         super(TarFileArchive, self).__init__(name, tmpdir, policy, threads,
-                                             enc_opts, sysroot)
+                                             enc_opts, sysroot, manifest)
         self._suffix = "tar"
         self._archive_name = os.path.join(tmpdir, self.name())
 
@@ -672,7 +694,7 @@ class TarFileArchive(FileCacheArchive):
     def _compress(self):
         methods = []
         # Make sure that valid compression commands exist.
-        for method in ['xz', 'bzip2', 'gzip']:
+        for method in ['xz', 'gzip']:
             if is_executable(method):
                 methods.append(method)
             else:
