@@ -1,8 +1,13 @@
-#!/usr/bin/env python
-
+# This file is part of the sos project: https://github.com/sosreport/sos
+#
+# This copyrighted material is made available to anyone wishing to use,
+# modify, copy, or redistribute it subject to the terms and conditions of
+# version 2 of the GNU General Public License.
+#
+# See the LICENSE file in the source distribution for further information.
 import unittest
 
-from sos.plugins import Plugin
+from sos.report.plugins import Plugin
 from sos.policies import LinuxPolicy, InitSystem
 
 
@@ -19,7 +24,8 @@ class GlobalOptionTest(unittest.TestCase):
         self.commons = {
             'sysroot': '/',
             'policy': LinuxPolicy(init=InitSystem()),
-            'cmdlineopts': MockOptions()
+            'cmdlineopts': MockOptions(),
+            'devices': {}
         }
         self.plugin = Plugin(self.commons)
         self.plugin.opt_names = ['baz', 'empty', 'test_option']
